<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace NCSU\Auth\Adapter;

use Exception;
use NCSU\Auth\AuthResult;
use NCSU\Auth\Exception\InvalidArgumentException;
use NCSU\Auth\Exception\RuntimeException;
use NCSU\Auth\Http\Request;

/**
 */
final class ChainedAuthAdapter implements AdapterInterface
{
    /**
     * @var AdapterInterface[]
     */
    protected $adapters;

    public function __construct(array $adapters = null)
    {
        $this->adapters = $adapters;

        if (is_null($adapters) or count($this->adapters) === 0) {
            $this->adapters = array(
                new ShibAuthAdapter(Request::createFromGlobals()),
                new WrapAuthAdapter(Request::createFromGlobals())
            );
        }
    }

    /**
     * Attempts to authenticate and returns user to client page.
     *
     * @throws RuntimeException
     * @return \NCSU\Auth\AuthResult
     */
    public function authenticate()
    {
        foreach ($this->adapters as $adapter) {
            try {
                $result = $adapter->authenticate();

                if ($result->isValid()) {
                    return new AuthResult(AuthResult::SUCCESS, $result->getIdentity());
                }
            } catch (\Exception $e) {
                continue;
            }
        }

        return new AuthResult(AuthResult::FAILURE, null);
    }
}
