<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace NCSU\Auth\Adapter;

use NCSU\Auth\AuthResult;

/**
 * Authentication adapter for authentication by LDAP at NC State.
 * @see http://ldap.ncsu.edu
 *
 * @author Dustin Wheeler <mdwheele@ncsu.edu>
 */
final class LdapAuthAdapter implements AdapterInterface
{
    const HOST = 'ldap.ncsu.edu';

    protected $identity;
    protected $password;

    function __construct($identity, $password)
    {
        $this->identity = $identity;
        $this->password = $password;
    }

    /**
     * Attempts to authenticate.
     *
     * @return \NCSU\Auth\AuthResult
     */
    public function authenticate()
    {
        $ldapConnection = @ldap_connect(LdapAuthAdapter::HOST);
        ldap_set_option($ldapConnection, LDAP_OPT_PROTOCOL_VERSION, 3);
        ldap_start_tls($ldapConnection);

        if ( ! $ldapConnection) {
            return new AuthResult(AuthResult::FAILURE);
        }

        $baseDn = sprintf("uid=%s,ou=accounts,dc=ncsu,dc=edu", $this->identity);
        $ldapBind = @ldap_bind($ldapConnection, $baseDn, $this->password);

        if ( ! $ldapBind) {
            return new AuthResult(AuthResult::FAILURE);
        }

        return new AuthResult(AuthResult::SUCCESS, $this->identity);
    }
}